diff --git a/src/Symfony/Bundle/FrameworkBundle/CHANGELOG.md b/src/Symfony/Bundle/FrameworkBundle/CHANGELOG.md
index 6df118bcc6b3c..a8c5b977942f5 100644
--- a/src/Symfony/Bundle/FrameworkBundle/CHANGELOG.md
+++ b/src/Symfony/Bundle/FrameworkBundle/CHANGELOG.md
@@ -25,7 +25,7 @@ CHANGELOG
* [BC BREAK] following session options: 'lifetime', 'path', 'domain', 'secure',
'httponly' are now prefixed with cookie_ when dumped to the container
* Added `handler_id` configuration under `session` key to represent `session.handler`
- service, defaults to `session.handler.native_file`.
+ service, defaults to `session.handler.file`.
* Added `gc_maxlifetime`, `gc_probability`, and `gc_divisor` to session
configuration. This means session garbage collection has a
`gc_probability`/`gc_divisor` chance of being run. The `gc_maxlifetime` defines
diff --git a/src/Symfony/Bundle/FrameworkBundle/Resources/config/session.xml b/src/Symfony/Bundle/FrameworkBundle/Resources/config/session.xml
index 871ea3ab9c09c..27631583d1002 100644
--- a/src/Symfony/Bundle/FrameworkBundle/Resources/config/session.xml
+++ b/src/Symfony/Bundle/FrameworkBundle/Resources/config/session.xml
@@ -10,7 +10,7 @@
Symfony\Component\HttpFoundation\Session\Attribute\AttributeBag
Symfony\Component\HttpFoundation\Session\Storage\NativeSessionStorage
Symfony\Component\HttpFoundation\Session\Storage\MockFileSessionStorage
- Symfony\Component\HttpFoundation\Session\Storage\Handler\NativeFileSessionHandler
+ Symfony\Component\HttpFoundation\Session\Storage\Handler\FileSessionHandler
Symfony\Bundle\FrameworkBundle\EventListener\SessionListener
@@ -34,7 +34,7 @@
%kernel.cache_dir%/sessions
-
+
%session.save_path%
@@ -45,5 +45,6 @@
+
diff --git a/src/Symfony/Component/HttpFoundation/CHANGELOG.md b/src/Symfony/Component/HttpFoundation/CHANGELOG.md
index 0309a5111478c..d8664e60bcf5a 100644
--- a/src/Symfony/Component/HttpFoundation/CHANGELOG.md
+++ b/src/Symfony/Component/HttpFoundation/CHANGELOG.md
@@ -21,12 +21,9 @@ CHANGELOG
* [BC BREAK] Moved all session related classes and interfaces into own namespace, as
`Symfony\Component\HttpFoundation\Session` and renamed classes accordingly.
Session handlers are located in the subnamespace `Symfony\Component\HttpFoundation\Session\Handler`.
- * SessionHandlers must implement `\SessionHandlerInterface` or extend from the
- `Symfony\Component\HttpFoundation\Storage\Handler\NativeSessionHandler` base class.
+ * SessionHandlers must implement `\SessionHandlerInterface`.
* Added internal storage driver proxy mechanism for forward compatibility with
PHP 5.4 `\SessionHandler` class.
- * Added session handlers for PHP native MongoDb, Memcache, Memcached, Redis and SQLite session
- save handlers.
* Added session handlers for custom Memcache, Memcached and Null session save handlers.
* [BC BREAK] Removed `NativeSessionStorage` and replaced with `NativeFileSessionHandler`.
* [BC BREAK] `SessionStorageInterface` methods removed: `write()`, `read()` and
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/FileSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/FileSessionHandler.php
new file mode 100644
index 0000000000000..1417b5ad8c2c9
--- /dev/null
+++ b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/FileSessionHandler.php
@@ -0,0 +1,115 @@
+
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
+
+namespace Symfony\Component\HttpFoundation\Session\Storage\Handler;
+
+/**
+ * FileSessionHandler.
+ *
+ * @author Drak
+ */
+class FileSessionHandler implements \SessionHandlerInterface
+{
+ /**
+ * @var string
+ */
+ private $savePath;
+
+ /**
+ * @var string
+ */
+ private $prefix;
+
+ /**
+ * Constructor.
+ *
+ * @param string $savePath Path of directory to save session files.
+ */
+ public function __construct($savePath = null, $prefix = 'sess_')
+ {
+ if (null === $savePath) {
+ $savePath = sys_get_temp_dir();
+ }
+
+ $this->savePath = $savePath;
+ if (false === is_dir($this->savePath)) {
+ mkdir($this->savePath, 0777, true);
+ }
+
+ $this->prefix = $prefix;
+ }
+
+ /**
+ * {@inheritdoc]
+ */
+ public function open($savePath, $sessionName)
+ {
+ return true;
+ }
+
+ /**
+ * {@inheritdoc]
+ */
+ public function close()
+ {
+ return true;
+ }
+
+ /**
+ * {@inheritdoc]
+ */
+ public function read($id)
+ {
+ $file = $this->getPath().$id;
+
+ return is_readable($file) ? file_get_contents($file) : '';
+ }
+
+ /**
+ * {@inheritdoc]
+ */
+ public function write($id, $data)
+ {
+ return false === file_put_contents($this->getPath().$id, $data) ? false : true;
+ }
+
+ /**
+ * {@inheritdoc]
+ */
+ public function destroy($id)
+ {
+ $file = $this->getPath().$id;
+ if (is_file($file)) {
+ unlink($file);
+ }
+
+ return true;
+ }
+
+ /**
+ * {@inheritdoc]
+ */
+ public function gc($maxlifetime)
+ {
+ foreach (glob($this->getPath().'*') as $file) {
+ if ((filemtime($file) + $maxlifetime) < time()) {
+ unlink($file);
+ }
+ }
+
+ return true;
+ }
+
+ private function getPath()
+ {
+ return $this->savePath.'/'.$this->prefix;
+ }
+}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeFileSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeFileSessionHandler.php
deleted file mode 100644
index 422e3a79a6ddd..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeFileSessionHandler.php
+++ /dev/null
@@ -1,41 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Session\Storage\Handler;
-
-/**
- * NativeFileSessionHandler.
- *
- * Native session handler using PHP's built in file storage.
- *
- * @author Drak
- */
-class NativeFileSessionHandler extends NativeSessionHandler
-{
- /**
- * Constructor.
- *
- * @param string $savePath Path of directory to save session files. Default null will leave setting as defined by PHP.
- */
- public function __construct($savePath = null)
- {
- if (null === $savePath) {
- $savePath = ini_get('session.save_path');
- }
-
- if ($savePath && !is_dir($savePath)) {
- mkdir($savePath, 0777, true);
- }
-
- ini_set('session.save_handler', 'files');
- ini_set('session.save_path', $savePath);
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeMemcacheSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeMemcacheSessionHandler.php
deleted file mode 100644
index 0b9c623558155..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeMemcacheSessionHandler.php
+++ /dev/null
@@ -1,68 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Session\Storage\Handler;
-
-/**
- * NativeMemcacheSessionHandler.
- *
- * Driver for the memcache session save handler provided by the memcache PHP extension.
- *
- * @see http://php.net/memcache
- *
- * @author Drak
- */
-class NativeMemcacheSessionHandler extends NativeSessionHandler
-{
- /**
- * Constructor.
- *
- * @param string $savePath Path of memcache server.
- * @param array $options Session configuration options.
- */
- public function __construct($savePath = 'tcp://127.0.0.1:11211?persistent=0', array $options = array())
- {
- if (!extension_loaded('memcache')) {
- throw new \RuntimeException('PHP does not have "memcache" session module registered');
- }
-
- if (null === $savePath) {
- $savePath = ini_get('session.save_path');
- }
-
- ini_set('session.save_handler', 'memcache');
- ini_set('session.save_path', $savePath);
-
- $this->setOptions($options);
- }
-
- /**
- * Set any memcached ini values.
- *
- * @see http://php.net/memcache.ini
- */
- protected function setOptions(array $options)
- {
- $validOptions = array_flip(array(
- 'memcache.allow_failover', 'memcache.max_failover_attempts',
- 'memcache.chunk_size', 'memcache.default_port', 'memcache.hash_strategy',
- 'memcache.hash_function', 'memcache.protocol', 'memcache.redundancy',
- 'memcache.session_redundancy', 'memcache.compress_threshold',
- 'memcache.lock_timeout',
- ));
-
- foreach ($options as $key => $value) {
- if (isset($validOptions[$key])) {
- ini_set($key, $value);
- }
- }
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeMemcachedSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeMemcachedSessionHandler.php
deleted file mode 100644
index ee9d75475ba82..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeMemcachedSessionHandler.php
+++ /dev/null
@@ -1,67 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Session\Storage\Handler;
-
-/**
- * NativeMemcachedSessionHandler.
- *
- * Driver for the memcached session save handler provided by the memcached PHP extension.
- *
- * @see http://php.net/memcached.sessions
- *
- * @author Drak
- */
-class NativeMemcachedSessionHandler extends NativeSessionHandler
-{
- /**
- * Constructor.
- *
- * @param string $savePath Comma separated list of servers: e.g. memcache1.example.com:11211,memcache2.example.com:11211
- * @param array $options Session configuration options.
- */
- public function __construct($savePath = '127.0.0.1:11211', array $options = array())
- {
- if (!extension_loaded('memcached')) {
- throw new \RuntimeException('PHP does not have "memcached" session module registered');
- }
-
- if (null === $savePath) {
- $savePath = ini_get('session.save_path');
- }
-
- ini_set('session.save_handler', 'memcached');
- ini_set('session.save_path', $savePath);
-
- $this->setOptions($options);
- }
-
- /**
- * Set any memcached ini values.
- *
- * @see https://github.com/php-memcached-dev/php-memcached/blob/master/memcached.ini
- */
- protected function setOptions(array $options)
- {
- $validOptions = array_flip(array(
- 'memcached.sess_locking', 'memcached.sess_lock_wait',
- 'memcached.sess_prefix', 'memcached.compression_type',
- 'memcached.compression_factor', 'memcached.compression_threshold',
- 'memcached.serializer',
- ));
-
- foreach ($options as $key => $value) {
- if (isset($validOptions[$key])) {
- ini_set($key, $value);
- }
- }
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeRedisSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeRedisSessionHandler.php
deleted file mode 100644
index e60c7f65589ba..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeRedisSessionHandler.php
+++ /dev/null
@@ -1,43 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Session\Storage\Handler;
-
-/**
- * NativeRedisSessionStorage.
- *
- * Driver for the redis session save handler provided by the redis PHP extension.
- *
- * @see https://github.com/nicolasff/phpredis
- *
- * @author Andrej Hudec
- */
-class NativeRedisSessionHandler extends NativeSessionHandler
-{
- /**
- * Constructor.
- *
- * @param string $savePath Path of redis server.
- */
- public function __construct($savePath = 'tcp://127.0.0.1:6379?persistent=0')
- {
- if (!extension_loaded('redis')) {
- throw new \RuntimeException('PHP does not have "redis" session module registered');
- }
-
- if (null === $savePath) {
- $savePath = ini_get('session.save_path');
- }
-
- ini_set('session.save_handler', 'redis');
- ini_set('session.save_path', $savePath);
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeSessionHandler.php
deleted file mode 100644
index 1260ad0d295a9..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeSessionHandler.php
+++ /dev/null
@@ -1,24 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Session\Storage\Handler;
-
-/**
- * Adds SessionHandler functionality if available.
- *
- * @see http://php.net/sessionhandler
- */
-
-if (version_compare(phpversion(), '5.4.0', '>=')) {
- class NativeSessionHandler extends \SessionHandler {}
-} else {
- class NativeSessionHandler {}
-}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeSqliteSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeSqliteSessionHandler.php
deleted file mode 100644
index ac034c29389fe..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NativeSqliteSessionHandler.php
+++ /dev/null
@@ -1,58 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Session\Storage\Handler;
-
-/**
- * NativeSqliteSessionHandler.
- *
- * Driver for the sqlite session save handler provided by the SQLite PHP extension.
- *
- * @author Drak
- */
-class NativeSqliteSessionHandler extends NativeSessionHandler
-{
- /**
- * Constructor.
- *
- * @param string $savePath Path to SQLite database file itself.
- * @param array $options Session configuration options.
- */
- public function __construct($savePath, array $options = array())
- {
- if (!extension_loaded('sqlite')) {
- throw new \RuntimeException('PHP does not have "sqlite" session module registered');
- }
-
- if (null === $savePath) {
- $savePath = ini_get('session.save_path');
- }
-
- ini_set('session.save_handler', 'sqlite');
- ini_set('session.save_path', $savePath);
-
- $this->setOptions($options);
- }
-
- /**
- * Set any sqlite ini values.
- *
- * @see http://php.net/sqlite.configuration
- */
- protected function setOptions(array $options)
- {
- foreach ($options as $key => $value) {
- if (in_array($key, array('sqlite.assoc_case'))) {
- ini_set($key, $value);
- }
- }
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NullSessionHandler.php b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NullSessionHandler.php
index dd9f0c79aebe9..62068aff1b7c7 100644
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NullSessionHandler.php
+++ b/src/Symfony/Component/HttpFoundation/Session/Storage/Handler/NullSessionHandler.php
@@ -14,7 +14,7 @@
/**
* NullSessionHandler.
*
- * Can be used in unit testing or in a sitation where persisted sessions are not desired.
+ * Can be used in unit testing or in a situations where persisted sessions are not desired.
*
* @author Drak
*
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/FileSessionHandlerTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/FileSessionHandlerTest.php
new file mode 100644
index 0000000000000..d935b34bd278c
--- /dev/null
+++ b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/FileSessionHandlerTest.php
@@ -0,0 +1,106 @@
+
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
+
+namespace Symfony\Component\HttpFoundation\Tests\Session\Storage\Handler;
+
+use Symfony\Component\HttpFoundation\Session\Storage\Handler\FileSessionHandler;
+
+/**
+ * Test class for FileSessionHandler.
+ *
+ * @author Drak
+ */
+class FileSessionStorageTest extends \PHPUnit_Framework_TestCase
+{
+ /**
+ * @var FileSessionHandler
+ */
+ private $handler;
+
+ /**
+ * @var string
+ */
+ private $path;
+
+ public function setUp()
+ {
+ $this->path = sys_get_temp_dir().'/filesessionhandler';
+ $this->handler = new FileSessionHandler($this->path, 'mocksess_');
+
+ parent::setUp();
+ }
+
+ public function tearDown()
+ {
+ foreach (glob($this->path.'/*') as $file) {
+ unlink($file);
+ }
+
+ rmdir($this->path);
+
+ $this->handler = null;
+ }
+
+ public function test__construct()
+ {
+ $this->assertTrue(is_dir($this->path));
+ }
+
+ public function testOpen()
+ {
+ $this->assertTrue($this->handler->open('a', 'b'));
+ }
+
+ public function testClose()
+ {
+ $this->assertTrue($this->handler->close());
+ }
+
+ public function testReadWrite()
+ {
+ $this->assertEmpty($this->handler->read('123'));
+ $this->assertTrue($this->handler->write('123', 'data'));
+ $this->assertEquals('data', $this->handler->read('123'));
+ }
+
+ public function testDestroy()
+ {
+ $this->handler->write('456', 'data');
+ $this->handler->destroy('123');
+ $this->assertEquals('data', $this->handler->read('456'));
+ $this->handler->destroy('456');
+ $this->assertEmpty($this->handler->read('456'));
+ }
+
+ public function testGc()
+ {
+ $prefix = $this->path.'/mocksess_';
+ $this->handler->write('1', 'data');
+ touch($prefix.'1', time()-86400);
+
+ $this->handler->write('2', 'data');
+ touch($prefix.'2', time()-3600);
+
+ $this->handler->write('3', 'data');
+ touch($prefix.'3', time()-300);
+
+ $this->handler->write('4', 'data');
+
+ $this->handler->gc(90000);
+ $this->assertEquals(4, count(glob($this->path.'/*')));
+
+ $this->handler->gc(4000);
+ $this->assertEquals(3, count(glob($this->path.'/*')));
+
+ $this->handler->gc(200);
+ $this->assertEquals(1, count(glob($this->path.'/*')));
+ }
+}
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeFileSessionHandlerTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeFileSessionHandlerTest.php
deleted file mode 100644
index 7bdf3a1e3ff0d..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeFileSessionHandlerTest.php
+++ /dev/null
@@ -1,49 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Tests\Session\Storage\Handler;
-
-use Symfony\Component\HttpFoundation\Session\Storage\Handler\NativeFileSessionHandler;
-use Symfony\Component\HttpFoundation\Session\Storage\NativeSessionStorage;
-
-/**
- * Test class for NativeFileSessionHandler.
- *
- * @author Drak
- *
- * @runTestsInSeparateProcesses
- */
-class NativeFileSessionHandlerTest extends \PHPUnit_Framework_TestCase
-{
- public function testConstruct()
- {
- $storage = new NativeSessionStorage(array('name' => 'TESTING'), new NativeFileSessionHandler(sys_get_temp_dir()));
-
- if (version_compare(phpversion(), '5.4.0', '<')) {
- $this->assertEquals('files', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('files', ini_get('session.save_handler'));
- } else {
- $this->assertEquals('files', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('user', ini_get('session.save_handler'));
- }
-
- $this->assertEquals(sys_get_temp_dir(), ini_get('session.save_path'));
- $this->assertEquals('TESTING', ini_get('session.name'));
- }
-
- public function testConstructDefault()
- {
- $path = ini_get('session.save_path');
- $storage = new NativeSessionStorage(array('name' => 'TESTING'), new NativeFileSessionHandler());
-
- $this->assertEquals($path, ini_get('session.save_path'));
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeMemcacheSessionHandlerTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeMemcacheSessionHandlerTest.php
deleted file mode 100644
index b915e59ca0916..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeMemcacheSessionHandlerTest.php
+++ /dev/null
@@ -1,45 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Tests\Session\Storage\Handler;
-
-use Symfony\Component\HttpFoundation\Session\Storage\Handler\NativeMemcacheSessionHandler;
-use Symfony\Component\HttpFoundation\Session\Storage\NativeSessionStorage;
-
-/**
- * Test class for NativeMemcacheSessionHandler.
- *
- * @author Drak
- *
- * @runTestsInSeparateProcesses
- */
-class NativeMemcacheSessionHandlerTest extends \PHPUnit_Framework_TestCase
-{
- public function testSaveHandlers()
- {
- if (!extension_loaded('memcache')) {
- $this->markTestSkipped('Skipped tests memcache extension is not present');
- }
-
- $storage = new NativeSessionStorage(array('name' => 'TESTING'), new NativeMemcacheSessionHandler('tcp://127.0.0.1:11211?persistent=0'));
-
- if (version_compare(phpversion(), '5.4.0', '<')) {
- $this->assertEquals('memcache', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('memcache', ini_get('session.save_handler'));
- } else {
- $this->assertEquals('memcache', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('user', ini_get('session.save_handler'));
- }
-
- $this->assertEquals('tcp://127.0.0.1:11211?persistent=0', ini_get('session.save_path'));
- $this->assertEquals('TESTING', ini_get('session.name'));
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeMemcachedSessionHandlerTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeMemcachedSessionHandlerTest.php
deleted file mode 100644
index 5f65e9a0fefa6..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeMemcachedSessionHandlerTest.php
+++ /dev/null
@@ -1,49 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Tests\Session\Storage\Handler;
-
-use Symfony\Component\HttpFoundation\Session\Storage\Handler\NativeMemcachedSessionHandler;
-use Symfony\Component\HttpFoundation\Session\Storage\NativeSessionStorage;
-
-/**
- * Test class for NativeMemcachedSessionHandler.
- *
- * @author Drak
- *
- * @runTestsInSeparateProcesses
- */
-class NativeMemcachedSessionHandlerTest extends \PHPUnit_Framework_TestCase
-{
- public function testSaveHandlers()
- {
- if (!extension_loaded('memcached')) {
- $this->markTestSkipped('Skipped tests memcached extension is not present');
- }
-
- // test takes too long if memcached server is not running
- ini_set('memcached.sess_locking', '0');
-
- $storage = new NativeSessionStorage(array('name' => 'TESTING'), new NativeMemcachedSessionHandler('127.0.0.1:11211'));
-
- if (version_compare(phpversion(), '5.4.0', '<')) {
- $this->assertEquals('memcached', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('memcached', ini_get('session.save_handler'));
- } else {
- $this->assertEquals('memcached', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('user', ini_get('session.save_handler'));
- }
-
- $this->assertEquals('127.0.0.1:11211', ini_get('session.save_path'));
- $this->assertEquals('TESTING', ini_get('session.name'));
- }
-}
-
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeRedisSessionHandlerTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeRedisSessionHandlerTest.php
deleted file mode 100644
index 8a5777659d88f..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeRedisSessionHandlerTest.php
+++ /dev/null
@@ -1,43 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Tests\Session\Storage;
-
-use Symfony\Component\HttpFoundation\Session\Storage\Handler\NativeRedisSessionHandler;
-use Symfony\Component\HttpFoundation\Session\Storage\NativeSessionStorage;
-
-/**
- * Test class for NativeRedisSessionHandlerTest.
- *
- * @runTestsInSeparateProcesses
- */
-class NativeRedisSessionHandlerTest extends \PHPUnit_Framework_TestCase
-{
- public function testSaveHandlers()
- {
- if (!extension_loaded('redis')) {
- $this->markTestSkipped('Skipped tests Redis extension is not present');
- }
-
- $storage = new NativeSessionStorage(array('name' => 'TESTING'), new NativeRedisSessionHandler('tcp://127.0.0.1:6379?persistent=0'));
-
- if (version_compare(phpversion(), '5.4.0', '<')) {
- $this->assertEquals('redis', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('redis', ini_get('session.save_handler'));
- } else {
- $this->assertEquals('redis', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('user', ini_get('session.save_handler'));
- }
-
- $this->assertEquals('tcp://127.0.0.1:6379?persistent=0', ini_get('session.save_path'));
- $this->assertEquals('TESTING', ini_get('session.name'));
- }
-}
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeSqliteSessionHandlerTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeSqliteSessionHandlerTest.php
deleted file mode 100644
index 983148e279502..0000000000000
--- a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/Handler/NativeSqliteSessionHandlerTest.php
+++ /dev/null
@@ -1,47 +0,0 @@
-
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
-
-namespace Symfony\Component\HttpFoundation\Tests\Session\Storage\Handler;
-
-use Symfony\Component\HttpFoundation\Session\Storage\Handler\NativeSqliteSessionHandler;
-use Symfony\Component\HttpFoundation\Session\Storage\NativeSessionStorage;
-
-/**
- * Test class for NativeSqliteSessionHandler.
- *
- * @author Drak
- *
- * @runTestsInSeparateProcesses
- */
-class NativeSqliteSessionHandlerTest extends \PHPUnit_Framework_TestCase
-{
- public function testSaveHandlers()
- {
- if (!extension_loaded('sqlite')) {
- $this->markTestSkipped('Skipped tests SQLite extension is not present');
- }
-
- $storage = new NativeSessionStorage(array('name' => 'TESTING'), new NativeSqliteSessionHandler(sys_get_temp_dir().'/sqlite.db'));
-
- if (version_compare(phpversion(), '5.4.0', '<')) {
- $this->assertEquals('sqlite', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('sqlite', ini_get('session.save_handler'));
- } else {
- $this->assertEquals('sqlite', $storage->getSaveHandler()->getSaveHandlerName());
- $this->assertEquals('user', ini_get('session.save_handler'));
- }
-
-
- $this->assertEquals(sys_get_temp_dir().'/sqlite.db', ini_get('session.save_path'));
- $this->assertEquals('TESTING', ini_get('session.name'));
- }
-}
-
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/MockFileSessionStorageTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/MockFileSessionStorageTest.php
index 9578ec98a8119..2ff05f367df05 100644
--- a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/MockFileSessionStorageTest.php
+++ b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/MockFileSessionStorageTest.php
@@ -28,7 +28,7 @@ class MockFileSessionStorageTest extends \PHPUnit_Framework_TestCase
private $sessionDir;
/**
- * @var FileMockSessionStorage
+ * @var MockFileSessionStorage
*/
protected $storage;
@@ -40,12 +40,14 @@ protected function setUp()
protected function tearDown()
{
+ foreach (glob($this->sessionDir.'/mocksess_*') as $file) {
+ unlink($file);
+ }
+
+ rmdir($this->sessionDir);
+
$this->sessionDir = null;
$this->storage = null;
- array_map('unlink', glob($this->sessionDir.'/*.session'));
- if (is_dir($this->sessionDir)) {
- rmdir($this->sessionDir);
- }
}
public function testStart()
diff --git a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/NativeSessionStorageTest.php b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/NativeSessionStorageTest.php
index 4b88a237a007e..528a1d7b02a24 100644
--- a/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/NativeSessionStorageTest.php
+++ b/src/Symfony/Component/HttpFoundation/Tests/Session/Storage/NativeSessionStorageTest.php
@@ -12,7 +12,6 @@
namespace Symfony\Component\HttpFoundation\Tests\Session\Storage;
use Symfony\Component\HttpFoundation\Session\Storage\NativeSessionStorage;
-use Symfony\Component\HttpFoundation\Session\Storage\Handler\NativeFileSessionHandler;
use Symfony\Component\HttpFoundation\Session\Storage\Handler\NullSessionHandler;
use Symfony\Component\HttpFoundation\Session\Flash\FlashBag;
use Symfony\Component\HttpFoundation\Session\Attribute\AttributeBag;
@@ -137,8 +136,8 @@ public function testSetSaveHandlerPHP53()
$this->markTestSkipped('Test skipped, for PHP 5.3 only.');
}
+ ini_set('session.save_handler', 'files');
$storage = $this->getStorage();
- $storage->setSaveHandler(new NativeFileSessionHandler());
$this->assertInstanceOf('Symfony\Component\HttpFoundation\Session\Storage\Proxy\NativeProxy', $storage->getSaveHandler());
}
diff --git a/src/Symfony/Component/HttpFoundation/Session/Storage/MockFileSessionStorage.php b/src/Symfony/Component/HttpFoundation/Session/Storage/MockFileSessionStorage.php
index 5bf2962ae65f1..964e24b5de83a 100644
--- a/src/Symfony/Component/HttpFoundation/Session/Storage/MockFileSessionStorage.php
+++ b/src/Symfony/Component/HttpFoundation/Session/Storage/MockFileSessionStorage.php
@@ -11,6 +11,9 @@
namespace Symfony\Component\HttpFoundation\Session\Storage;
+use Symfony\Component\HttpFoundation\Session\Storage\Handler\FileSessionHandler;
+use Symfony\Component\HttpFoundation\Session\Storage\MetadataBag;
+
/**
* MockFileSessionStorage is used to mock sessions for
* functional testing when done in a single PHP process.
@@ -25,31 +28,32 @@
class MockFileSessionStorage extends MockArraySessionStorage
{
/**
- * @var string
+ * @var array
*/
- private $savePath;
-
private $sessionData;
+ /**
+ * @var FileSessionHandler
+ */
+ private $handler;
+
/**
* Constructor.
*
* @param string $savePath Path of directory to save session files.
* @param string $name Session name.
*/
- public function __construct($savePath = null, $name = 'MOCKSESSID')
+ public function __construct($savePath = null, $name = 'MOCKSESSID', FileSessionHandler $handler = null, MetadataBag $metaData = null)
{
- if (null === $savePath) {
- $savePath = sys_get_temp_dir();
- }
-
- if (!is_dir($savePath)) {
- mkdir($savePath, 0777, true);
+ if (null == $handler) {
+ $handler = new FileSessionHandler($savePath, 'mocksess_');
}
- $this->savePath = $savePath;
+ $this->handler = $handler;
- parent::__construct($name);
+ parent::__construct($name, $metaData);
}
/**
@@ -93,7 +97,7 @@ public function regenerate($destroy = false, $lifetime = null)
*/
public function save()
{
- file_put_contents($this->getFilePath(), serialize($this->data));
+ $this->handler->write($this->id, serialize($this->data));
}
/**
@@ -102,19 +106,7 @@ public function save()
*/
private function destroy()
{
- if (is_file($this->getFilePath())) {
- unlink($this->getFilePath());
- }
- }
-
- /**
- * Calculate path to file.
- *
- * @return string File path
- */
- private function getFilePath()
- {
- return $this->savePath.'/'.$this->id.'.mocksess';
+ $this->handler->destroy($this->id);
}
/**
@@ -122,8 +114,8 @@ private function getFilePath()
*/
private function read()
{
- $filePath = $this->getFilePath();
- $this->data = is_readable($filePath) && is_file($filePath) ? unserialize(file_get_contents($filePath)) : array();
+ $data = $this->handler->read($this->id);
+ $this->data = $data ? unserialize($data) : array();
$this->loadSession();
}
@@ -25,31 +28,32 @@
* Constructor.
*
- * @param string $savePath Path of directory to save session files.
- * @param string $name Session name.
+ * @param string $savePath Path of directory to save session files.
+ * @param string $name Session name.
+ * @param FileSessionHandler $handler Save handler
+ * @param MetadataBag $metaData Metadatabag
*/